pub struct UnitSimple<S>where
S: MeasureSystem,{
pub ratio: <S as MeasureSystem>::N,
pub offset: <S as MeasureSystem>::N,
}Expand description
A Simple Unit in a given MeasureSystem
The equations for Unit are as follows:
self.to_base = (val + self.offset) * self.ratio
self.to_self = (val / self.ratio) - self.offset
If greater flexibility is required, please see `UnitTrait
Fields
ratio: <S as MeasureSystem>::Noffset: <S as MeasureSystem>::NTrait Implementations
Sourceimpl<S> Debug for UnitSimple<S>where
S: MeasureSystem,
impl<S> Debug for UnitSimple<S>where
S: MeasureSystem,
Sourceimpl<S> PartialEq for UnitSimple<S>
impl<S> PartialEq for UnitSimple<S>
Sourceimpl<S> UnitTrait for UnitSimple<S>where
S: MeasureSystem,
impl<S> UnitTrait for UnitSimple<S>where
S: MeasureSystem,
type System = S
Sourcefn from(&self, val: <S as MeasureSystem>::N) -> Measure<S>
fn from(&self, val: <S as MeasureSystem>::N) -> Measure<S>
Generate a new Measure from this unit and value
Sourcefn to_base(&self, val: <S as MeasureSystem>::N) -> <S as MeasureSystem>::N
fn to_base(&self, val: <S as MeasureSystem>::N) -> <S as MeasureSystem>::N
Convert the given value as this unit into the base unit Read more
Sourcefn to_self(&self, val: <S as MeasureSystem>::N) -> <S as MeasureSystem>::N
fn to_self(&self, val: <S as MeasureSystem>::N) -> <S as MeasureSystem>::N
Convert the value as the base unit into this unit Read more
impl<S> StructuralPartialEq for UnitSimple<S>where
S: MeasureSystem,